@@ -1,5 +1,5 @@
 package MediaWiki::CleanupHTML;
-$MediaWiki::CleanupHTML::VERSION = '0.0.4';
+$MediaWiki::CleanupHTML::VERSION = '0.0.5';
 use 5.008;
 
 use strict;
@@ -179,9 +179,14 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+MediaWiki::CleanupHTML - cleanup the MediaWiki-generated HTML from MediaWiki
+embellishments.
+
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -207,11 +212,6 @@ and return a more straightforward HTML. Note that the HTML returned by
 MediaWiki APIs may not always available (for instance if the wiki is down), so
 this module should be considered a fallback.
 
-=head1 NAME
-
-MediaWiki::CleanupHTML - cleanup the MediaWiki-generated HTML from MediaWiki
-embellishments.
-
 =head1 SUBROUTINES/METHODS
 
 =head2 MediaWiki::CleanupHTML->new({fh => $fh})
@@ -298,7 +298,7 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -335,14 +335,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=MediaWiki-CleanupHTML>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/MediaWiki-CleanupHTML>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
